        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 22 <strong>control</strong><br>0,6,10,12,14,15,18,19,21,24,25,26,29,32,33,34,35,36,39,43,47,49';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 16 <br>2,4,16,20,22,23,27,28,31,37,38,40,41,44,45,48';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260611 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>1,3,5,7,8,9,11,13,17,30,42,46,50';}
}
